@@ -13,30 +13,35 @@ class InstallWarning(Warning):
     def __str__(self):
         return repr(self.message)
 
+
 try: 
-    from scpantheon import qt, source 
+    from scpantheon import qt, source # import from online
 except:
     warnings.warn('YOU HAVE TO INSTALL PyQt5',InstallWarning)
 
 def run():
+    global server
     print('Opening Bokeh application on http://localhost:5006/')
     # sourceqt.qt_button()
     server = Server({'/': source.main},
                     allow_websocket_origin=["localhost:5006"], port=5006, show=False, num_procs=1) 
     server.start()  
-    
     server.io_loop.start()
     server.show()
 
-
 def app():
-    global p1
     if qt.main() == 'app closed':
         p1.terminate()
         print('app ended')
     
 
-if __name__ == '__main__':
+def main():
+    global p1
     p1 = multiprocessing.Process(target=run)
     p1.start()
     app()
+
+
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
