@@ -1249,5 +1249,5 @@ def fetch():
     print("=== test result ===")
     for x in result:
         print(x)
-    print("=== test finished ===")
+    print("=== test finished hhh ===")
     return result[-2][0], result[-1][0]
\ No newline at end of file
